==> dltk-sdk-R-2.0-201006161315.zip: org/eclipse/dltk/python/internal/ui/PythonUI.java <==
/*******************************************************************************
 * Copyright (c) 2005, 2007 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 
 *******************************************************************************/
package org.eclipse.dltk.python.internal.ui;

import org.eclipse.dltk.python.internal.ui.text.PythonTextTools;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.BundleContext;


/**
 * The activator class controls the plug-in life cycle
 */
public class PythonUI extends AbstractUIPlugin {

	// The plug-in ID
	public static final String PLUGIN_ID = "org.eclipse.dltk.python.ui";

	// The shared instance
	private static PythonUI plugin;
	
	private PythonTextTools fPythonTextTools;
	
	/**
	 * The constructor
	 */
	public PythonUI() {
		plugin = this;
	}

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.ui.plugin.AbstractUIPlugin#start(org.osgi.framework.BundleContext)
	 */
	public void start(BundleContext context) throws Exception {
		super.start(context);
	}

	/*
	 * (non-Javadoc)
	 * @see org.eclipse.ui.plugin.AbstractUIPlugin#stop(org.osgi.framework.BundleContext)
	 */
	public void stop(BundleContext context) throws Exception {
		plugin = null;
		super.stop(context);
	}

	/**
	 * Returns the shared instance
	 *
	 * @return the shared instance
	 */
	public static PythonUI getDefault() {
		return plugin;
	}
	
	public synchronized PythonTextTools getTextTools() {
		if (fPythonTextTools == null)
			fPythonTextTools= new PythonTextTools(true);
		return fPythonTextTools;
	}	

}

==> dltk-sdk-R-5.10-201808292040.zip: org/eclipse/dltk/python/internal/ui/PythonUI.java <==
/*******************************************************************************
 * Copyright (c) 2005, 2016 IBM Corporation and others.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 *******************************************************************************/
package org.eclipse.dltk.python.internal.ui;

import org.eclipse.dltk.python.internal.ui.text.PythonTextTools;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.BundleContext;


/**
 * The activator class controls the plug-in life cycle
 */
public class PythonUI extends AbstractUIPlugin {

	// The plug-in ID
	public static final String PLUGIN_ID = "org.eclipse.dltk.python.ui";

	// The shared instance
	private static PythonUI plugin;

	private PythonTextTools fPythonTextTools;

	/**
	 * The constructor
	 */
	public PythonUI() {
		plugin = this;
	}

	@Override
	public void start(BundleContext context) throws Exception {
		super.start(context);
	}

	@Override
	public void stop(BundleContext context) throws Exception {
		plugin = null;
		super.stop(context);
	}

	/**
	 * Returns the shared instance
	 *
	 * @return the shared instance
	 */
	public static PythonUI getDefault() {
		return plugin;
	}

	public synchronized PythonTextTools getTextTools() {
		if (fPythonTextTools == null)
			fPythonTextTools= new PythonTextTools(true);
		return fPythonTextTools;
	}

}
